==> freecol_0.11.6+dfsg.orig.tar.xz: freecol/src/net/sf/freecol/client/gui/action/DeclareIndependenceAction.java <==
/**
 *  Copyright (C) 2002-2015   The FreeCol Team
 *
 *  This file is part of FreeCol.
 *
 *  FreeCol is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  FreeCol is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.freecol.client.gui.action;

import java.awt.event.ActionEvent;

import net.sf.freecol.client.FreeColClient;
import net.sf.freecol.common.model.Player;
import net.sf.freecol.common.model.Player.PlayerType;


/**
 * An action for declaring independence.
 */
public class DeclareIndependenceAction extends MapboardAction {

    public static final String id = "declareIndependenceAction";


    /**
     * Creates a new <code>DeclareIndependenceAction</code>.
     *
     * @param freeColClient The <code>FreeColClient</code> for the game.
     */
    public DeclareIndependenceAction(FreeColClient freeColClient) {
        super(freeColClient, id);
    }


    // Override FreeColAction

    /**
     * {@inheritDoc}
     */
    @Override
    protected boolean shouldBeEnabled() {
        Player p = freeColClient.getMyPlayer();
        return super.shouldBeEnabled() && p != null
            && p.getPlayerType() == PlayerType.COLONIAL;
    }


    // Interface ActionListener

    /**
     * {@inheritDoc}
     */
    @Override
    public void actionPerformed(ActionEvent ae) {
        igc().declareIndependence();
    }
}

==> freecol_1.2.0.orig.tar.xz: freecol/src/net/sf/freecol/client/gui/action/DeclareIndependenceAction.java <==
/**
 *  Copyright (C) 2002-2022   The FreeCol Team
 *
 *  This file is part of FreeCol.
 *
 *  FreeCol is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  FreeCol is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.freecol.client.gui.action;

import java.awt.event.ActionEvent;

import net.sf.freecol.client.FreeColClient;
import net.sf.freecol.common.model.Player;
import net.sf.freecol.common.model.Player.PlayerType;


/**
 * An action for declaring independence.
 */
public class DeclareIndependenceAction extends MapboardAction {

    public static final String id = "declareIndependenceAction";


    /**
     * Creates a new {@code DeclareIndependenceAction}.
     *
     * @param freeColClient The {@code FreeColClient} for the game.
     */
    public DeclareIndependenceAction(FreeColClient freeColClient) {
        super(freeColClient, id);
    }


    // Override FreeColAction

    /**
     * {@inheritDoc}
     */
    @Override
    protected boolean shouldBeEnabled() {
        Player p = freeColClient.getMyPlayer();
        return p != null && p.getPlayerType() == PlayerType.COLONIAL
            && super.shouldBeEnabled();
    }


    // Interface ActionListener

    /**
     * {@inheritDoc}
     */
    @Override
    public void actionPerformed(ActionEvent ae) {
        igc().declareIndependence();
    }
}
